pub const DEFAULT: [&str; 40] = [
    "arg",
    "assert",
    "collectgarbage",
    "coroutine",
    "debug",
    "dofile",
    "error",
    "gcinfo",
    "getfenv",
    "getmetatable",
    "io",
    "ipairs",
    "load",
    "loadfile",
    "loadstring",
    "math",
    "module",
    "newproxy",
    "next",
    "os",
    "package",
    "pairs",
    "pcall",
    "print",
    "rawequal",
    "rawget",
    "rawset",
    "require",
    "select",
    "setfenv",
    "setmetatable",
    "string",
    "table",
    "tonumber",
    "tostring",
    "type",
    "unpack",
    "xpcall",
    "_G",
    "_VERSION",
];

pub const ROBLOX: [&str; 58] = [
    "Axes",
    "bit32",
    "BrickColor",
    "CatalogSearchParams",
    "CellId",
    "ColorSequence",
    "ColorSequenceKeypoint",
    "Color3",
    "CFrame",
    "DateTime",
    "DebuggerManager",
    "delay",
    "DockWidgetPluginGuiInfo",
    "elapsedTime",
    "Enum",
    "Faces",
    "Instance",
    "LoadLibrary",
    "game",
    "NumberRange",
    "NumberSequence",
    "NumberSequenceKeypoint",
    "OverlapParams",
    "PathWaypoint",
    "PhysicalProperties",
    "plugin",
    "PluginDrag",
    "PluginManager",
    "printidentity",
    "Random",
    "Ray",
    "RaycastParams",
    "Rect",
    "Region3",
    "Region3int16",
    "script",
    "settings",
    "shared",
    "stats",
    "spawn",
    "task",
    "tick",
    "time",
    "TweenInfo",
    "typeof",
    "UDim",
    "UDim2",
    "UserSettings",
    "utf8",
    "Vector2",
    "Vector2int16",
    "Vector3",
    "Vector3int16",
    "version",
    "wait",
    "warn",
    "workspace",
    "ypcall",
];
